import setuptools
setuptools.setup(
    name='hymath',
    version='0.0.2',
    author='Dingdang Wang',
    author_email='1330274738@qq.com',
    description='学而思火焰工作室数学库',
    long_descripition_content_type="text/markdown",
    url='https://github.com/',
    packages=setuptools.find_packages(),
    classifiers= [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent" ,
    ],
)